#############
API reference
#############

.. automodapi:: safir
   :include-all-objects:

.. automodapi:: safir.http
   :include-all-objects:

.. automodapi:: safir.logging
   :include-all-objects:

.. automodapi:: safir.metadata
   :include-all-objects:

.. automodapi:: safir.middleware
   :include-all-objects:
